@@ -87,7 +87,7 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
    "Nothing", "Exit", "Netlist", "Swap", "Pin Label", "Pin Global",
    "Info Label", "Graphic", "Rescale", "Connectivity", "Sim", "SPICE",
-   "PCB", "SPICE Flat",
+   "PCB", "SPICE Flat", "Text Delete Param",
    NULL			/* sentinel */
 };
 
@@ -534,6 +534,7 @@ void default_keybindings()
    add_vbinding(XK_KP_Prior, XCF_Justify, 8);
 
    add_binding(XK_Delete, XCF_Text_Delete);
+   add_binding(SHIFT | XK_Delete, XCF_Text_Delete_Param);
    add_binding(XK_Return, XCF_Text_Return);
    add_binding(XK_BackSpace, XCF_Text_Delete);
    add_binding(XK_Left, XCF_Text_Left);
