@@ -1006,14 +1006,14 @@ void setfilename(xcWidget w, char **dataptr)
    if (!strcmp(*dataptr, _STR2)) return;   /* no change in string */
 
    /* Make the change to the current page */
-   xobjs.pagelist[areastruct.page]->filename = mystrdup(_STR2);
+   xobjs.pagelist[areastruct.page]->filename = strdup(_STR2);
 
    /* All existing filenames which match the old string should also be changed */
    for (cpage = 0; cpage < xobjs.pages; cpage++) {
       if ((xobjs.pagelist[cpage]->pageinst != NULL) && (cpage != areastruct.page)) {
 	 if (!strcmp(xobjs.pagelist[cpage]->filename, oldstr)) {
 	    free(xobjs.pagelist[cpage]->filename);
-	    xobjs.pagelist[cpage]->filename = mystrdup(_STR2);
+	    xobjs.pagelist[cpage]->filename = strdup(_STR2);
 	 }
       }
    }
@@ -1400,7 +1400,7 @@ void getgridtype(xcWidget button, pointertype value, caddr_t calldata)
 
 void newlibrary(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   int libnum = createlibrary();
+   int libnum = createlibrary(FALSE);
    startcatalog(w, libnum, NULL);
 }
 
@@ -1424,10 +1424,13 @@ int findemptylib()
 
 /*----------------------------------------------*/
 /* Make new library and add a new button to the */
-/* "Libraries" cascaded menu.			*/
+/* "Libraries" cascaded menu.	If "force" is	*/
+/* FALSE, then return the number of the first	*/
+/* empty library found.  If "force" is TRUE,	*/
+/* then always create a new library.		*/ 
 /*----------------------------------------------*/
 
-int createlibrary()
+int createlibrary(Boolean force)
 {
    xcWidget libmenu, newbutton, oldbutton;
    Arg wargs[2];
@@ -1436,7 +1439,7 @@ int createlibrary()
    objectptr newlibobj;
 
    /* If there's an empty library, return its number */
-   if ((libnum = findemptylib()) >= 0) return (libnum + LIBRARY);
+   if ((!force) && (libnum = findemptylib()) >= 0) return (libnum + LIBRARY);
    libnum = (xobjs.numlibs++) + LIBRARY;
    xobjs.libtop = (objinstptr *)realloc(xobjs.libtop,
 		(libnum + 1) * sizeof(objinstptr));
@@ -1581,6 +1584,9 @@ void renamepage(short pagenumber)
       Fprintf(stderr, "Error:  No Button Widget named \"%9s\"\n", bname);
 #endif
 
+   /* The GUI has been taken care of, but the page itself might not exist */
+   if (!thisinst) return;
+
    /* If the page had a master but now has a different	*/
    /* name, disconnect the schematics.			*/
 
@@ -1607,7 +1613,6 @@ void renamepage(short pagenumber)
 	 break;
       }
    }
-
 }
 
 /*--------------------------------------------------------------*/
